
package interfazgrafica5;

import javax.swing.JButton;
import javax.swing.JLabel;

public class Componentes {

    private JLabel jLabelVisualizaPulsacionesBoton;
    private JLabel jLabelVisualizaPulsacionesRaton;
    private JLabel jLabelVisualizaPosicionRaton;    
    private JButton jButtonContar;   
    private int contadorPulsacionesBoton; 
    private int contadorPulsacionesRaton;

    public JLabel getjLabelVisualizaPulsacionesBoton() {
        return jLabelVisualizaPulsacionesBoton;
    }

    public void setjLabelVisualizaPulsacionesBoton(JLabel jLabelVisualizaPulsacionesBoton) {
        this.jLabelVisualizaPulsacionesBoton = jLabelVisualizaPulsacionesBoton;
    }    

    public JLabel getjLabelVisualizaPulsacionesRaton() {
        return jLabelVisualizaPulsacionesRaton;
    }

    public void setjLabelVisualizaPulsacionesRaton(JLabel jLabelVisualizaPulsacionesRaton) {
        this.jLabelVisualizaPulsacionesRaton = jLabelVisualizaPulsacionesRaton;
    }    
    
    public JLabel getjLabelVisualizaPosicionRaton() {
        return jLabelVisualizaPosicionRaton;
    }

    public void setjLabelVisualizaPosicionRaton(JLabel jLabelVisualizaPosicionRaton) {
        this.jLabelVisualizaPosicionRaton = jLabelVisualizaPosicionRaton;
    }

    public JButton getjButtonContar() {
        return jButtonContar;
    }

    public void setjButtonContar(JButton jButtonContar) {
        this.jButtonContar = jButtonContar;
    }

    public int getContadorPulsacionesBoton() {
        return contadorPulsacionesBoton;
    }

    public void setContadorPulsacionesBoton(int contadorPulsacionesBoton) {
        this.contadorPulsacionesBoton = contadorPulsacionesBoton;
    }

    public int getContadorPulsacionesRaton() {
        return contadorPulsacionesRaton;
    }

    public void setContadorPulsacionesRaton(int contadorPulsacionesRaton) {
        this.contadorPulsacionesRaton = contadorPulsacionesRaton;
    } 
}
